@@ -26,6 +26,7 @@ import re
 
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
+    'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
     'default_mod_dir':    '/usr/lib/python3.8/site-packages',
@@ -35,15 +36,15 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/include/python3.8',
     'py_inc_dir':         '/usr/include/python3.8',
     'py_lib_dir':         '/usr/lib/python3.8/config',
-    'py_version':         0x030803,
+    'py_version':         0x030805,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_config_args':    'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'sip_inc_dir':        '/usr/include/python3.8',
     'sip_module_dir':     '/usr/lib/python3.8/site-packages',
     'sip_root_dir':       '/usr/lib/python3.8/site-packages',
-    'sip_version':        0x041317,
-    'sip_version_str':    '4.19.23',
+    'sip_version':        0x041318,
+    'sip_version_str':    '4.19.24',
     'universal':          ''
 }
 
@@ -51,7 +52,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fstack-protector-strong -fno-plt',
+    'CFLAGS':                   '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O2 -pipe -fno-plt',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
